@@ -380,9 +380,8 @@ bool DolphinContextMenu::placeExists(const QUrl &url) const
 {
     const KFilePlacesModel *placesModel = DolphinPlacesModelSingleton::instance().placesModel();
 
-    const auto &matchedPlaces = placesModel->match(placesModel->index(0, 0), KFilePlacesModel::UrlRole, url, 1, Qt::MatchExactly);
-
-    return !matchedPlaces.isEmpty();
+    QModelIndex url_index = placesModel->closestItem(url);
+    return url_index.isValid() && placesModel->url(url_index).matches(url, QUrl::StripTrailingSlash);
 }
 
 QAction *DolphinContextMenu::createPasteAction()
