@@ -42,14 +42,19 @@ class KFileItem;
 class KFileItemList;
 class KJob;
 class KNewFileMenu;
+class KRecentFilesAction;
 class KToolBarPopupAction;
 class QToolButton;
 class PlacesPanel;
 class TerminalPanel;
 
+/** Used to identify that a custom command should be triggered on a view background double-click.*/
+constexpr QLatin1String customCommand{"CUSTOM_COMMAND"};
+
 namespace KIO
 {
 class OpenUrlJob;
+class CommandLauncherJob;
 }
 namespace SelectionMode
 {
@@ -131,6 +136,11 @@ public:
     bool isInformationPanelEnabled() const;
     bool isSplitViewEnabledInCurrentTab() const;
 
+    /**
+     * Activates a user set action when double clicking the view's background.
+     */
+    void slotDoubleClickViewBackground(Qt::MouseButton button);
+
 public Q_SLOTS:
     /**
      * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
@@ -748,6 +758,10 @@ private:
     QFutureWatcher<void> *m_sessionSaveWatcher;
     bool m_sessionSaveScheduled;
 
+    KIO::CommandLauncherJob *m_job;
+
+    KRecentFilesAction *m_recentFiles = nullptr;
+
     friend class DolphinMainWindowTest;
 };
 
