@@ -46,23 +46,20 @@ ViewProperties::ViewProperties(const QUrl &url)
     // We try and save it to the file .directory in the directory being viewed.
     // If the directory is not writable by the user or the directory is not local,
     // we store the properties information in a local file.
-    if (useGlobalViewProps) {
-        m_filePath = destinationDir(QStringLiteral("global"));
-    } else if (url.scheme().contains(QLatin1String("search"))) {
+    if (url.scheme().contains(QLatin1String("search"))) {
         m_filePath = destinationDir(QStringLiteral("search/")) + directoryHashForUrl(url);
         useSearchView = true;
     } else if (url.scheme() == QLatin1String("trash")) {
         m_filePath = destinationDir(QStringLiteral("trash"));
         useTrashView = true;
-    } else if (url.scheme() == QLatin1String("recentdocuments")) {
-        m_filePath = destinationDir(QStringLiteral("recentdocuments"));
-        useRecentDocumentsView = true;
     } else if (url.scheme() == QLatin1String("recentlyused")) {
         m_filePath = destinationDir(QStringLiteral("recentlyused"));
         useRecentDocumentsView = true;
     } else if (url.scheme() == QLatin1String("timeline")) {
         m_filePath = destinationDir(QStringLiteral("timeline"));
         useRecentDocumentsView = true;
+    } else if (useGlobalViewProps) {
+        m_filePath = destinationDir(QStringLiteral("global"));
     } else if (url.isLocalFile()) {
         m_filePath = url.toLocalFile();
 
